@@ -914,15 +914,6 @@ function stop_manila {
     done
 }
 
-function install_manila_tempest_plugin {
-    MANILA_TEMPEST_PLUGIN_REPO=${MANILA_TEMPEST_PLUGIN_REPO:-${GIT_BASE}/openstack/manila-tempest-plugin}
-    MANILA_TEMPEST_PLUGIN_BRANCH=${MANILA_TEMPEST_PLUGIN_BRANCH:-master}
-    MANILA_TEMPEST_PLUGIN_DIR=$DEST/manila-tempest-plugin
-
-    git_clone $MANILA_TEMPEST_PLUGIN_REPO $MANILA_TEMPEST_PLUGIN_DIR $MANILA_TEMPEST_PLUGIN_BRANCH
-    setup_develop $MANILA_TEMPEST_PLUGIN_DIR
-}
-
 # update_tempest - Function used for updating Tempest config if Tempest service enabled
 function update_tempest {
     if is_service_enabled tempest; then
@@ -956,10 +947,21 @@ function update_tempest {
         iniset $TEMPEST_CONFIG identity alt_tenant_name ${ALT_TENANT_NAME:-"alt_demo"}
         iniset $TEMPEST_CONFIG identity alt_domain_name $ADMIN_DOMAIN_NAME
 
-        # Max API micro-version for tempest tests
-        iniset $TEMPEST_CONFIG share min_api_microversion 2.0
-        iniset $TEMPEST_CONFIG share max_api_microversion 2.63
-
+        # If testing a stable branch, we need to ensure we're testing with supported
+        # API micro-versions; so set the versions from code if we're not testing the
+        # master branch. If we're testing master, we'll allow manila-tempest-plugin
+        # (which is branchless) tell us what versions it wants to test.
+        if [[ "$TARGET_BRANCH" != "master" ]]; then
+            # Grab the supported API micro-versions from the code
+            _DEFAULT_MIN_VERSION=$(openstack --os-cloud devstack versions show --service sharev2 -c 'Min Microversion' --status CURRENT -f value)
+            _DEFAULT_MAX_VERSION=$(openstack --os-cloud devstack versions show --service sharev2 -c 'Max Microversion' --status CURRENT -f value)
+            # Override the *_api_microversion tempest options if present
+            MANILA_TEMPEST_MIN_API_MICROVERSION=${MANILA_TEMPEST_MIN_API_MICROVERSION:-$_DEFAULT_MIN_VERSION}
+            MANILA_TEMPEST_MAX_API_MICROVERSION=${MANILA_TEMPEST_MAX_API_MICROVERSION:-$_DEFAULT_MAX_VERSION}
+            # Set these options in tempest.conf
+            iniset $TEMPEST_CONFIG share min_api_microversion $MANILA_TEMPEST_MIN_API_MICROVERSION
+            iniset $TEMPEST_CONFIG share max_api_microversion $MANILA_TEMPEST_MAX_API_MICROVERSION
+        fi
     fi
 }
 
@@ -970,7 +972,7 @@ function install_docker_ubuntu {
 }
 
 function install_docker_fedora {
-    sudo yum install -y docker
+    install_package docker
     sudo systemctl enable docker
     sudo systemctl start docker
 }
@@ -1307,17 +1309,6 @@ elif [[ "$1" == "stack" && "$2" == "test-config" ]]; then
     fi
     ###########################################################################
 
-
-    if [ $(trueorfalse False MANILA_INSTALL_TEMPEST_PLUGIN_SYSTEMWIDE) == True ]; then
-        echo_summary "Fetching and installing manila-tempest-plugin system-wide"
-        install_manila_tempest_plugin
-        export DEPRECATED_TEXT="$DEPRECATED_TEXT\nInstalling
-        manila-tempest-plugin can be done with the help of its own DevStack
-        plugin by adding: \n\n\t'enable_plugin manila-tempest-plugin
-        https://opendev.org/openstack/manila-tempest-plugin'.\n\nManila's
-        DevStack plugin will stop installing it automatically."
-    fi
-
     echo_summary "Update Tempest config"
     update_tempest
 
