@@ -53,8 +53,6 @@
   CLI interface for manila management.
 """
 
-from __future__ import print_function
-
 import os
 import sys
 
@@ -80,6 +78,10 @@ HOST_UPDATE_HELP_MSG = ("A fully qualified host string is of the format "
 HOST_UPDATE_CURRENT_HOST_HELP = ("Current share host name. %s" %
                                  HOST_UPDATE_HELP_MSG)
 HOST_UPDATE_NEW_HOST_HELP = "New share host name. %s" % HOST_UPDATE_HELP_MSG
+SHARE_SERVERS_UPDATE_HELP = ("List of share servers to be updated, separated "
+                             "by commas.")
+SHARE_SERVERS_UPDATE_CAPABILITIES_HELP = (
+    "List of share server capabilities to be updated, separated by commas.")
 
 
 # Decorators for actions
@@ -346,6 +348,17 @@ class ServiceCommands(object):
                 svc['updated_at'],
             ))
 
+    def cleanup(self):
+        """Remove manila services reporting as 'down'."""
+        ctxt = context.get_admin_context()
+        services = db.service_get_all(ctxt)
+
+        for svc in services:
+            if utils.service_is_up(svc):
+                continue
+            db.service_destroy(ctxt, svc['id'])
+            print("Cleaned up service %s" % svc['host'])
+
 
 class ShareCommands(object):
 
@@ -366,19 +379,64 @@ class ShareCommands(object):
     @args('--force', required=False, type=bool, default=False,
           help="Ignore validations.")
     def update_host(self, current_host, new_host, force=False):
-        """Modify the host name associated with a share.
+        """Modify the host name associated with resources.
 
            Particularly to recover from cases where one has moved
            their Manila Share node, or modified their 'host' opt
            or their backend section name in the manila configuration file.
+           Affects shares, share servers and share groups
         """
         if not force:
             self._validate_hosts(current_host, new_host)
         ctxt = context.get_admin_context()
-        updated = db.share_instances_host_update(ctxt, current_host, new_host)
-        print("Updated host of %(count)s share instances on %(chost)s "
-              "to %(nhost)s." % {'count': updated, 'chost': current_host,
-                                 'nhost': new_host})
+        updated = db.share_resources_host_update(ctxt, current_host, new_host)
+        msg = ("Updated host of %(si_count)d share instances, "
+               "%(sg_count)d share groups and %(ss_count)d share servers on "
+               "%(chost)s to %(nhost)s.")
+        msg_args = {
+            'si_count': updated['instances'],
+            'sg_count': updated['groups'],
+            'ss_count': updated['servers'],
+            'chost': current_host,
+            'nhost': new_host,
+        }
+        print(msg % msg_args)
+
+
+class ShareServerCommands(object):
+    @args('--share_servers', required=True,
+          help=SHARE_SERVERS_UPDATE_HELP)
+    @args('--capabilities', required=True,
+          help=SHARE_SERVERS_UPDATE_CAPABILITIES_HELP)
+    @args('--value', required=False, type=bool, default=False,
+          help="If those capabilities will be enabled (True) or disabled "
+               "(False)")
+    def update_share_server_capabilities(self, share_servers, capabilities,
+                                         value=False):
+        """Update the share server capabilities.
+
+           This method receives a list of share servers and capabilities
+           in order to have it updated with the value specified. If the value
+           was not specified the default is False.
+        """
+        share_servers = [server.strip() for server in share_servers.split(",")]
+        capabilities = [cap.strip() for cap in capabilities.split(",")]
+        supported_capabilities = ['security_service_update_support']
+
+        values = dict()
+        for capability in capabilities:
+            if capability not in supported_capabilities:
+                print("One or more capabilities are invalid for this "
+                      "operation. The supported capability(ies) is(are) %s."
+                      % supported_capabilities)
+                sys.exit(1)
+            values[capability] = value
+
+        ctxt = context.get_admin_context()
+        db.share_servers_update(ctxt, share_servers, values)
+        print("The capability(ies) %s of the following share server(s)"
+              " %s was(were) updated to %s." %
+              (capabilities, share_servers, value))
 
 
 CATEGORIES = {
@@ -388,6 +446,7 @@ CATEGORIES = {
     'logs': GetLogCommands,
     'service': ServiceCommands,
     'share': ShareCommands,
+    'share_server': ShareServerCommands,
     'shell': ShellCommands,
     'version': VersionCommands
 }
