@@ -140,6 +140,7 @@ class DummyDriver(driver.ShareDriver):
         self.backend_name = self.configuration.safe_get(
             "share_backend_name") or "DummyDriver"
         self.migration_progress = {}
+        self.security_service_update_support = True
 
     def _verify_configuration(self):
         allowed_driver_methods = [m for m in dir(self) if m[0] != '_']
@@ -431,7 +432,10 @@ class DummyDriver(driver.ShareDriver):
             "pool_name": "fake_pool_for_%s" % self.backend_name,
             "total_capacity_gb": 1230.0,
             "free_capacity_gb": 1210.0,
-            "reserved_percentage": self.configuration.reserved_share_percentage
+            "reserved_percentage":
+                self.configuration.reserved_share_percentage,
+            "reserved_snapshot_percentage":
+                self.configuration.reserved_share_from_snapshot_percentage
         }]
         if self.configuration.replication_domain:
             pools[0]["replication_type"] = "readable"
@@ -445,6 +449,8 @@ class DummyDriver(driver.ShareDriver):
             "storage_protocol": "NFS_CIFS",
             "reserved_percentage":
                 self.configuration.reserved_share_percentage,
+            "reserved_snapshot_percentage":
+                self.configuration.reserved_share_from_snapshot_percentage,
             "snapshot_support": True,
             "create_share_from_snapshot_support": True,
             "revert_to_snapshot_support": True,
@@ -453,7 +459,7 @@ class DummyDriver(driver.ShareDriver):
             "pools": self._get_pools_info(),
             "share_group_stats": {
                 "consistent_snapshot_support": "pool",
-            }
+            },
         }
         if self.configuration.replication_domain:
             data["replication_type"] = "readable"
@@ -710,7 +716,7 @@ class DummyDriver(driver.ShareDriver):
             'nondisruptive': False,
             'share_network_id': new_share_network['id'],
             'migration_cancel': compatible,
-            'migration_get_progress': compatible
+            'migration_get_progress': compatible,
         }
 
     @slow_me_down
@@ -852,3 +858,34 @@ class DummyDriver(driver.ShareDriver):
             'export_locations': self.private_storage.get(share['id'],
                                                          key='export_location')
         }
+
+    @slow_me_down
+    def update_share_server_security_service(self, context, share_server,
+                                             network_info, share_instances,
+                                             share_instance_rules,
+                                             new_security_service,
+                                             current_security_service=None):
+        if current_security_service:
+            msg = _("Replacing security service %(cur_sec_serv_id)s by "
+                    "security service %(new_sec_serv_id)s on share server "
+                    "%(server_id)s."
+                    ) % {
+                'cur_sec_serv_id': current_security_service['id'],
+                'new_sec_serv_id': new_security_service['id'],
+                'server_id': share_server['id']
+            }
+        else:
+            msg = _("Adding security service %(sec_serv_id)s on share server "
+                    "%(server_id)s."
+                    ) % {
+                'sec_serv_id': new_security_service['id'],
+                'server_id': share_server['id']
+            }
+
+        LOG.debug(msg)
+
+    def check_update_share_server_security_service(
+            self, context, share_server, network_info, share_instances,
+            share_instance_rules, new_security_service,
+            current_security_service=None):
+        return True
