@@ -38,6 +38,7 @@ test_config.tegile_nas_server = 'some-ip'
 test_config.tegile_nas_login = 'some-user'
 test_config.tegile_nas_password = 'some-password'
 test_config.reserved_share_percentage = 10
+test_config.reserved_share_from_snapshot_percentage = 5
 test_config.max_over_subscription_ratio = 30.0
 
 test_share = {
@@ -82,6 +83,7 @@ array_stats = {
             'QoS_support': False,
             'free_capacity_gb': 911.812650680542,
             'reserved_percentage': 0,
+            'reserved_snapshot_percentage': 0,
             'pool_name': 'pyramid',
         },
         {
@@ -89,6 +91,7 @@ array_stats = {
             'QoS_support': False,
             'free_capacity_gb': 2740.148867149747,
             'reserved_percentage': 0,
+            'reserved_snapshot_percentage': 0,
             'pool_name': 'cobalt',
         },
         {
@@ -96,6 +99,7 @@ array_stats = {
             'QoS_support': False,
             'free_capacity_gb': 913.4198722839355,
             'reserved_percentage': 0,
+            'reserved_snapshot_percentage': 0,
             'pool_name': 'test',
         },
     ],
@@ -447,6 +451,7 @@ class TegileShareDriverTestCase(test.TestCase):
                     'pool_name': 'pyramid',
                     'qos': False,
                     'reserved_percentage': 10,
+                    'reserved_snapshot_percentage': 5,
                     'thin_provisioning': True,
                     'max_over_subscription_ratio': 30.0,
                     'total_capacity_gb': 913.5},
@@ -458,6 +463,7 @@ class TegileShareDriverTestCase(test.TestCase):
                     'pool_name': 'cobalt',
                     'qos': False,
                     'reserved_percentage': 10,
+                    'reserved_snapshot_percentage': 5,
                     'thin_provisioning': True,
                     'max_over_subscription_ratio': 30.0,
                     'total_capacity_gb': 2742.1996604874
@@ -470,11 +476,13 @@ class TegileShareDriverTestCase(test.TestCase):
                     'pool_name': 'test',
                     'qos': False,
                     'reserved_percentage': 10,
+                    'reserved_snapshot_percentage': 5,
                     'thin_provisioning': True,
                     'max_over_subscription_ratio': 30.0,
                     'total_capacity_gb': 913.5}, ],
             'qos': False,
             'reserved_percentage': 0,
+            'reserved_snapshot_percentage': 0,
             'replication_domain': None,
             'share_backend_name': 'Tegile',
             'snapshot_support': True,
